==> haskell-ipynb-0.1-74-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ipynb
version: 0.1
id: ipynb-0.1-D4ezWq0MGWLF4lRubMVQdO
key: ipynb-0.1-D4ezWq0MGWLF4lRubMVQdO
license: BSD-3-Clause
copyright: Copyright (C) 2019 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
synopsis: Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.
category: Text
abi: faab93cb7fcc64f3e8350018169ccbb7
exposed: True
exposed-modules:
    Data.Ipynb
import-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ipynb-0.1
hs-libraries: HSipynb-0.1-D4ezWq0MGWLF4lRubMVQdO
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
haddock-interfaces: /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html: /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipynb-0.1-86-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ipynb
version: 0.1
id: ipynb-0.1-JFWKFotoSC29j0QGrvpqcU
key: ipynb-0.1-JFWKFotoSC29j0QGrvpqcU
license: BSD-3-Clause
copyright: Copyright (C) 2019 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
synopsis: Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.
category: Text
abi: f55a24f3db8b8506dc0ad0fed5500eac
exposed: True
exposed-modules:
    Data.Ipynb
import-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ipynb-0.1
hs-libraries: HSipynb-0.1-JFWKFotoSC29j0QGrvpqcU
depends:
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
haddock-interfaces: /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html: /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
